<?php

namespace Vidgyor\Video\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Vidgyor\Video\Interfaces\VideoRepositoryInterface;

class VideoPublicController extends BaseController
{
    // use VideoWorkflow;

    /**
     * Constructor.
     *
     * @param type \Vidgyor\Video\Interfaces\VideoRepositoryInterface $video
     *
     * @return type
     */
    public function __construct(VideoRepositoryInterface $video)
    {
        $this->repository = $video;
        parent::__construct();
    }

    /**
     * Show video's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $videos = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$video::video.names'))
            ->view('video::video.index')
            ->data(compact('videos'))
            ->output();
    }


    /**
     * Show video.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $video = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$video->name . trans('video::video.name'))
            ->view('video::video.show')
            ->data(compact('video'))
            ->output();
    }

}
