<?php

namespace Vidgyor\Video\Policies;

use Litepie\User\Contracts\UserPolicy;
use Vidgyor\Video\Models\Video;

class VideoPolicy
{

    /**
     * Determine if the given user can view the video.
     *
     * @param UserPolicy $user
     * @param Video $video
     *
     * @return bool
     */
    public function view(UserPolicy $user, Video $video)
    {
        if ($user->canDo('video.video.view') && $user->isAdmin()) {
            return true;
        }

        return $video->user_id == user_id() && $video->user_type == user_type();
    }

    /**
     * Determine if the given user can create a video.
     *
     * @param UserPolicy $user
     * @param Video $video
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('video.video.create');
    }

    /**
     * Determine if the given user can update the given video.
     *
     * @param UserPolicy $user
     * @param Video $video
     *
     * @return bool
     */
    public function update(UserPolicy $user, Video $video)
    {
        if ($user->canDo('video.video.edit') && $user->isAdmin()) {
            return true;
        }

        return $video->user_id == user_id() && $video->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given video.
     *
     * @param UserPolicy $user
     * @param Video $video
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Video $video)
    {
        return $video->user_id == user_id() && $video->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given video.
     *
     * @param UserPolicy $user
     * @param Video $video
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Video $video)
    {
        if ($user->canDo('video.video.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given video.
     *
     * @param UserPolicy $user
     * @param Video $video
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Video $video)
    {
        if ($user->canDo('video.video.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
